@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -44,24 +44,18 @@ struct LIBJAMI_PUBLIC Message
 };
 
 LIBJAMI_PUBLIC std::map<std::string, std::string> getAccountDetails(const std::string& accountId);
-LIBJAMI_PUBLIC std::map<std::string, std::string> getVolatileAccountDetails(
-    const std::string& accountId);
-LIBJAMI_PUBLIC void setAccountDetails(const std::string& accountId,
-                                      const std::map<std::string, std::string>& details);
-LIBJAMI_PUBLIC void setAccountActive(const std::string& accountId,
-                                     bool active,
-                                     bool shutdownConnections = false);
-LIBJAMI_PUBLIC void loadAccountAndConversation(const std::string& accountId,
-                                               bool loadAll,
-                                               const std::string& convId);
+LIBJAMI_PUBLIC std::map<std::string, std::string> getVolatileAccountDetails(const std::string& accountId);
+LIBJAMI_PUBLIC void setAccountDetails(const std::string& accountId, const std::map<std::string, std::string>& details);
+LIBJAMI_PUBLIC void setAccountActive(const std::string& accountId, bool active, bool shutdownConnections = false);
+LIBJAMI_PUBLIC void loadAccountAndConversation(const std::string& accountId, bool loadAll, const std::string& convId);
 LIBJAMI_PUBLIC std::map<std::string, std::string> getAccountTemplate(const std::string& accountType);
 LIBJAMI_PUBLIC std::string addAccount(const std::map<std::string, std::string>& details,
                                       const std::string& accountId = {});
 LIBJAMI_PUBLIC void monitor(bool continuous);
-LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getConnectionList(
-    const std::string& accountId, const std::string& conversationId);
-LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getChannelList(
-    const std::string& accountId, const std::string& connectionId);
+LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getConnectionList(const std::string& accountId,
+                                                                                 const std::string& conversationId);
+LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getChannelList(const std::string& accountId,
+                                                                              const std::string& connectionId);
 
 LIBJAMI_PUBLIC bool provideAccountAuthentication(const std::string& accountId,
                                                  const std::string& credentialsFromUser,
@@ -84,15 +78,10 @@ LIBJAMI_PUBLIC bool changeAccountPassword(const std::string& accountId,
                                           const std::string& password_old,
                                           const std::string& password_new);
 LIBJAMI_PUBLIC bool isPasswordValid(const std::string& accountId, const std::string& password);
-LIBJAMI_PUBLIC std::vector<uint8_t> getPasswordKey(const std::string& accountId,
-                                                   const std::string& password);
+LIBJAMI_PUBLIC std::vector<uint8_t> getPasswordKey(const std::string& accountId, const std::string& password);
 
-LIBJAMI_PUBLIC bool lookupName(const std::string& account,
-                               const std::string& nameserver,
-                               const std::string& name);
-LIBJAMI_PUBLIC bool lookupAddress(const std::string& account,
-                                  const std::string& nameserver,
-                                  const std::string& address);
+LIBJAMI_PUBLIC bool lookupName(const std::string& account, const std::string& nameserver, const std::string& name);
+LIBJAMI_PUBLIC bool lookupAddress(const std::string& account, const std::string& nameserver, const std::string& address);
 LIBJAMI_PUBLIC bool registerName(const std::string& account,
                                  const std::string& name,
                                  const std::string& scheme = {},
@@ -108,8 +97,7 @@ LIBJAMI_PUBLIC uint64_t sendAccountTextMessage(const std::string& accountId,
                                                const std::map<std::string, std::string>& payloads,
                                                int32_t flags);
 LIBJAMI_PUBLIC bool cancelMessage(const std::string& accountId, uint64_t message);
-LIBJAMI_PUBLIC std::vector<Message> getLastMessages(const std::string& accountId,
-                                                    const uint64_t& base_timestamp);
+LIBJAMI_PUBLIC std::vector<Message> getLastMessages(const std::string& accountId, const uint64_t& base_timestamp);
 LIBJAMI_PUBLIC std::map<std::string, std::string> getNearbyPeers(const std::string& accountId);
 LIBJAMI_PUBLIC void updateProfile(const std::string& accountId,
                                   const std::string& displayName,
@@ -118,9 +106,7 @@ LIBJAMI_PUBLIC void updateProfile(const std::string& accountId,
                                   int32_t flag);
 LIBJAMI_PUBLIC int getMessageStatus(uint64_t id);
 LIBJAMI_PUBLIC int getMessageStatus(const std::string& accountId, uint64_t id);
-LIBJAMI_PUBLIC void setIsComposing(const std::string& accountId,
-                                   const std::string& conversationUri,
-                                   bool isWriting);
+LIBJAMI_PUBLIC void setIsComposing(const std::string& accountId, const std::string& conversationUri, bool isWriting);
 LIBJAMI_PUBLIC bool setMessageDisplayed(const std::string& accountId,
                                         const std::string& conversationUri,
                                         const std::string& messageId,
@@ -129,15 +115,13 @@ LIBJAMI_PUBLIC bool setMessageDisplayed(const std::string& accountId,
 LIBJAMI_PUBLIC std::vector<unsigned> getCodecList();
 LIBJAMI_PUBLIC std::vector<std::string> getSupportedTlsMethod();
 LIBJAMI_PUBLIC std::vector<std::string> getSupportedCiphers(const std::string& accountId);
-LIBJAMI_PUBLIC std::map<std::string, std::string> getCodecDetails(const std::string& accountId,
-                                                                  const unsigned& codecId);
+LIBJAMI_PUBLIC std::map<std::string, std::string> getCodecDetails(const std::string& accountId, const unsigned& codecId);
 LIBJAMI_PUBLIC bool setCodecDetails(const std::string& accountId,
                                     const unsigned& codecId,
                                     const std::map<std::string, std::string>& details);
 LIBJAMI_PUBLIC std::vector<unsigned> getActiveCodecList(const std::string& accountId);
 
-LIBJAMI_PUBLIC void setActiveCodecList(const std::string& accountId,
-                                       const std::vector<unsigned>& list);
+LIBJAMI_PUBLIC void setActiveCodecList(const std::string& accountId, const std::vector<unsigned>& list);
 
 LIBJAMI_PUBLIC std::vector<std::string> getAudioPluginList();
 LIBJAMI_PUBLIC void setAudioPlugin(const std::string& audioPlugin);
@@ -155,6 +139,8 @@ LIBJAMI_PUBLIC std::string getNoiseSuppressState();
 LIBJAMI_PUBLIC void setNoiseSuppressState(const std::string& state);
 LIBJAMI_PUBLIC std::string getEchoCancellationState();
 LIBJAMI_PUBLIC void setEchoCancellationState(const std::string& state);
+LIBJAMI_PUBLIC bool getVoiceActivityDetectionState();
+LIBJAMI_PUBLIC void setVoiceActivityDetectionState(bool state);
 
 LIBJAMI_PUBLIC bool isAgcEnabled();
 LIBJAMI_PUBLIC void setAgcState(bool enabled);
@@ -190,8 +176,7 @@ LIBJAMI_PUBLIC int32_t getRingingTimeout();
 
 LIBJAMI_PUBLIC void setAccountsOrder(const std::string& order);
 
-LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getCredentials(
-    const std::string& accountId);
+LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getCredentials(const std::string& accountId);
 LIBJAMI_PUBLIC void setCredentials(const std::string& accountId,
                                    const std::vector<std::map<std::string, std::string>>& details);
 
@@ -206,22 +191,20 @@ LIBJAMI_PUBLIC double getVolume(const std::string& device);
 /*
  * Security
  */
-LIBJAMI_PUBLIC std::map<std::string, std::string> validateCertificate(
-    const std::string& accountId, const std::string& certificate);
-LIBJAMI_PUBLIC std::map<std::string, std::string> validateCertificatePath(
-    const std::string& accountId,
-    const std::string& certificatePath,
-    const std::string& privateKey,
-    const std::string& privateKeyPassword,
-    const std::string& caList);
+LIBJAMI_PUBLIC std::map<std::string, std::string> validateCertificate(const std::string& accountId,
+                                                                      const std::string& certificate);
+LIBJAMI_PUBLIC std::map<std::string, std::string> validateCertificatePath(const std::string& accountId,
+                                                                          const std::string& certificatePath,
+                                                                          const std::string& privateKey,
+                                                                          const std::string& privateKeyPassword,
+                                                                          const std::string& caList);
 
-LIBJAMI_PUBLIC std::map<std::string, std::string> getCertificateDetails(
-    const std::string& accountId, const std::string& certificate);
-LIBJAMI_PUBLIC std::map<std::string, std::string> getCertificateDetailsPath(
-    const std::string& accountId,
-    const std::string& certificatePath,
-    const std::string& privateKey,
-    const std::string& privateKeyPassword);
+LIBJAMI_PUBLIC std::map<std::string, std::string> getCertificateDetails(const std::string& accountId,
+                                                                        const std::string& certificate);
+LIBJAMI_PUBLIC std::map<std::string, std::string> getCertificateDetailsPath(const std::string& accountId,
+                                                                            const std::string& certificatePath,
+                                                                            const std::string& privateKey,
+                                                                            const std::string& privateKeyPassword);
 
 LIBJAMI_PUBLIC std::vector<std::string> getPinnedCertificates(const std::string& accountId);
 
@@ -237,12 +220,10 @@ LIBJAMI_PUBLIC bool pinRemoteCertificate(const std::string& accountId, const std
 LIBJAMI_PUBLIC bool setCertificateStatus(const std::string& account,
                                          const std::string& certId,
                                          const std::string& status);
-LIBJAMI_PUBLIC std::vector<std::string> getCertificatesByStatus(const std::string& account,
-                                                                const std::string& status);
+LIBJAMI_PUBLIC std::vector<std::string> getCertificatesByStatus(const std::string& account, const std::string& status);
 
 /* contact requests */
-LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getTrustRequests(
-    const std::string& accountId);
+LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getTrustRequests(const std::string& accountId);
 LIBJAMI_PUBLIC bool acceptTrustRequest(const std::string& accountId, const std::string& from);
 LIBJAMI_PUBLIC bool discardTrustRequest(const std::string& accountId, const std::string& from);
 LIBJAMI_PUBLIC void sendTrustRequest(const std::string& accountId,
@@ -255,8 +236,7 @@ LIBJAMI_PUBLIC void addContact(const std::string& accountId, const std::string&
 LIBJAMI_PUBLIC void removeContact(const std::string& accountId, const std::string& uri, bool ban);
 LIBJAMI_PUBLIC std::map<std::string, std::string> getContactDetails(const std::string& accountId,
                                                                     const std::string& uri);
-LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getContacts(
-    const std::string& accountId);
+LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getContacts(const std::string& accountId);
 
 /*
  * Network connectivity
@@ -284,8 +264,7 @@ LIBJAMI_PUBLIC void setPushNotificationConfig(const std::map<std::string, std::s
 /**
  * To be called by clients with relevant data when a push notification is received.
  */
-LIBJAMI_PUBLIC void pushNotificationReceived(const std::string& from,
-                                             const std::map<std::string, std::string>& data);
+LIBJAMI_PUBLIC void pushNotificationReceived(const std::string& from, const std::map<std::string, std::string>& data);
 
 /**
  * Returns whether or not the audio meter is enabled for ring buffer @id.
@@ -304,9 +283,7 @@ LIBJAMI_PUBLIC void setAudioMeterState(const std::string& id, bool state);
 /**
  * Add/remove default moderator for conferences
  */
-LIBJAMI_PUBLIC void setDefaultModerator(const std::string& accountId,
-                                        const std::string& peerURI,
-                                        bool state);
+LIBJAMI_PUBLIC void setDefaultModerator(const std::string& accountId, const std::string& peerURI, bool state);
 
 /**
  * Get default moderators for an account
@@ -435,8 +412,7 @@ struct LIBJAMI_PUBLIC ConfigurationSignal
     struct LIBJAMI_PUBLIC NeedsHost
     {
         constexpr static const char* name = "NeedsHost";
-        using cb_type = void(const std::string& /*account_id*/,
-                             const std::string& /*conversation_id*/);
+        using cb_type = void(const std::string& /*account_id*/, const std::string& /*conversation_id*/);
     };
     struct LIBJAMI_PUBLIC ActiveCallsChanged
     {
@@ -472,16 +448,12 @@ struct LIBJAMI_PUBLIC ConfigurationSignal
     struct LIBJAMI_PUBLIC ContactAdded
     {
         constexpr static const char* name = "ContactAdded";
-        using cb_type = void(const std::string& /*account_id*/,
-                             const std::string& /*uri*/,
-                             bool confirmed);
+        using cb_type = void(const std::string& /*account_id*/, const std::string& /*uri*/, bool confirmed);
     };
     struct LIBJAMI_PUBLIC ContactRemoved
     {
         constexpr static const char* name = "ContactRemoved";
-        using cb_type = void(const std::string& /*account_id*/,
-                             const std::string& /*uri*/,
-                             bool banned);
+        using cb_type = void(const std::string& /*account_id*/, const std::string& /*uri*/, bool banned);
     };
     // struct LIBJAMI_PUBLIC ExportToPeer
     // {
@@ -496,8 +468,7 @@ struct LIBJAMI_PUBLIC ConfigurationSignal
     struct LIBJAMI_PUBLIC KnownDevicesChanged
     {
         constexpr static const char* name = "KnownDevicesChanged";
-        using cb_type = void(const std::string& /*account_id*/,
-                             const std::map<std::string, std::string>& devices);
+        using cb_type = void(const std::string& /*account_id*/, const std::map<std::string, std::string>& devices);
     };
     struct LIBJAMI_PUBLIC RegisteredNameFound
     {
@@ -524,8 +495,7 @@ struct LIBJAMI_PUBLIC ConfigurationSignal
     struct LIBJAMI_PUBLIC CertificatePathPinned
     {
         constexpr static const char* name = "CertificatePathPinned";
-        using cb_type = void(const std::string& /*path*/,
-                             const std::vector<std::string>& /*certId*/);
+        using cb_type = void(const std::string& /*path*/, const std::vector<std::string>& /*certId*/);
     };
     struct LIBJAMI_PUBLIC CertificateExpired
     {
@@ -552,9 +522,7 @@ struct LIBJAMI_PUBLIC ConfigurationSignal
     struct LIBJAMI_PUBLIC DeviceRevocationEnded
     {
         constexpr static const char* name = "DeviceRevocationEnded";
-        using cb_type = void(const std::string& /*accountId*/,
-                             const std::string& /*device*/,
-                             int /*status*/);
+        using cb_type = void(const std::string& /*accountId*/, const std::string& /*device*/, int /*status*/);
     };
     struct LIBJAMI_PUBLIC AccountProfileReceived
     {
